package com.ruoyi.generator.service;

import java.util.List;
import com.ruoyi.generator.domain.SysProjectModule;

/**
 * 功能模块与项目关系Service接口
 * 
 * @author ruoyi
 * @date 2025-05-09
 */
public interface ISysProjectModuleService 
{
    /**
     * 查询功能模块与项目关系
     * 
     * @param id 功能模块与项目关系主键
     * @return 功能模块与项目关系
     */
    public SysProjectModule selectSysProjectModuleById(Long id);

    /**
     * 查询功能模块与项目关系列表
     * 
     * @param sysProjectModule 功能模块与项目关系
     * @return 功能模块与项目关系集合
     */
    public List<SysProjectModule> selectSysProjectModuleList(SysProjectModule sysProjectModule);

    /**
     * 新增功能模块与项目关系
     * 
     * @param sysProjectModule 功能模块与项目关系
     * @return 结果
     */
    public int insertSysProjectModule(SysProjectModule sysProjectModule);

    /**
     * 修改功能模块与项目关系
     * 
     * @param sysProjectModule 功能模块与项目关系
     * @return 结果
     */
    public int updateSysProjectModule(SysProjectModule sysProjectModule);

    /**
     * 批量删除功能模块与项目关系
     * 
     * @param ids 需要删除的功能模块与项目关系主键集合
     * @return 结果
     */
    public int deleteSysProjectModuleByIds(Long[] ids);

    /**
     * 删除功能模块与项目关系信息
     * 
     * @param id 功能模块与项目关系主键
     * @return 结果
     */
    public int deleteSysProjectModuleById(Long id);
}
