package com.ruoyi.generator.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.alibaba.druid.support.json.JSONUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.generator.domain.SysProjectModule;
import com.ruoyi.generator.service.ISysProjectModuleService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 功能模块与项目关系Controller
 * 
 * @author ruoyi
 * @date 2025-05-09
 */
@RestController
@RequestMapping("/generator/project/module")
public class SysProjectModuleController extends BaseController
{
    @Autowired
    private ISysProjectModuleService sysProjectModuleService;

    /**
     * 查询功能模块与项目关系列表
     */
    @PreAuthorize("@ss.hasPermi('generator:module:list')")
    @GetMapping("/list")
    public TableDataInfo list(SysProjectModule sysProjectModule)
    {
        startPage();
        List<SysProjectModule> list = sysProjectModuleService.selectSysProjectModuleList(sysProjectModule);
        return getDataTable(list);
    }

    /**
     * 导出功能模块与项目关系列表
     */
    @PreAuthorize("@ss.hasPermi('generator:module:export')")
    @Log(title = "功能模块与项目关系", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysProjectModule sysProjectModule)
    {
        List<SysProjectModule> list = sysProjectModuleService.selectSysProjectModuleList(sysProjectModule);
        ExcelUtil<SysProjectModule> util = new ExcelUtil<SysProjectModule>(SysProjectModule.class);
        util.exportExcel(response, list, "功能模块与项目关系数据");
    }

    /**
     * 获取功能模块与项目关系详细信息
     */
    @PreAuthorize("@ss.hasPermi('generator:module:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(sysProjectModuleService.selectSysProjectModuleById(id));
    }

    /**
     * 新增功能模块与项目关系
     */
    @PreAuthorize("@ss.hasPermi('generator:module:add')")
    @Log(title = "功能模块与项目关系", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody SysProjectModule sysProjectModule)
    {
        return toAjax(sysProjectModuleService.insertSysProjectModule(sysProjectModule));
    }

    /**
     * 修改功能模块与项目关系
     */
    @PreAuthorize("@ss.hasPermi('generator:module:edit')")
    @Log(title = "功能模块与项目关系", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody SysProjectModule sysProjectModule)
    {
        return toAjax(sysProjectModuleService.updateSysProjectModule(sysProjectModule));
    }

    /**
     * 删除功能模块与项目关系
     */
    @PreAuthorize("@ss.hasPermi('generator:module:remove')")
    @Log(title = "功能模块与项目关系", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(sysProjectModuleService.deleteSysProjectModuleByIds(ids));
    }
}
